@@ -5,6 +5,8 @@ import os
 import pkg_resources
 import re
 import shutil
+import magic
+from datetime import timezone
 
 from feedgen.feed import FeedGenerator
 from jinja2 import Template
@@ -20,9 +22,12 @@ class Build:
     template = None
     db = None
 
-    def __init__(self, config, db):
+    def __init__(self, config, db, symlink):
         self.config = config
         self.db = db
+        self.symlink = symlink
+
+        self.rss_template: Template = None
 
         # Map of all message IDs across all months and the slug of the page
         # in which they occur (paginated), used to link replies to their
@@ -85,8 +90,11 @@ class Build:
 
         # The last page chronologically is the latest page. Make it index.
         if fname:
-            shutil.copy(os.path.join(self.config["publish_dir"], fname),
-                        os.path.join(self.config["publish_dir"], "index.html"))
+            if self.symlink:
+                os.symlink(fname, os.path.join(self.config["publish_dir"], "index.html"))
+            else:
+                shutil.copy(os.path.join(self.config["publish_dir"], fname),
+                            os.path.join(self.config["publish_dir"], "index.html"))
 
         # Generate RSS feeds.
         if self.config["publish_rss_feed"]:
@@ -96,6 +104,10 @@ class Build:
         with open(fname, "r") as f:
             self.template = Template(f.read())
 
+    def load_rss_template(self, fname):
+        with open(fname, "r") as f:
+            self.rss_template = Template(f.read())
+
     def make_filename(self, month, page) -> str:
         fname = "{}{}.html".format(
             month.slug, "_" + str(page) if page > 1 else "")
@@ -131,18 +143,33 @@ class Build:
             e = f.add_entry()
             e.id(url)
             e.title("@{} on {} (#{})".format(m.user.username, m.date, m.id))
-            e.description(self._make_abstract(m))
+            e.published(m.date.replace(tzinfo=timezone.utc))
+            e.link({"href": url})
 
+            media_mime = ""
             if m.media and m.media.url:
                 murl = "{}/{}/{}".format(self.config["site_url"],
                                          os.path.basename(self.config["media_dir"]), m.media.url)
-                e.enclosure(murl, 0, "application/octet-stream")
+                try:
+                    media_path = "{}/{}".format(self.config["media_dir"], m.media.url)
+                    media_mime = magic.from_file(media_path, mime=True)
+                    media_size = str(os.path.getsize(media_path))
+                except FileNotFoundError:
+                    media_mime = "application/octet-stream"
+                    media_size = 0
+                e.enclosure(murl, media_size, media_mime)
+            e.content(self._make_abstract(m, media_mime), type="html")
 
-            f.rss_file(os.path.join(self.config["publish_dir"], "index.xml"))
-            f.atom_file(os.path.join(
-                self.config["publish_dir"], "index.atom"))
+        f.rss_file(os.path.join(self.config["publish_dir"], "index.xml"))
+        f.atom_file(os.path.join(self.config["publish_dir"], "index.atom"))
 
-    def _make_abstract(self, m):
+    def _make_abstract(self, m, media_mime):
+        if self.rss_template:
+            return self.rss_template.render(config=self.config,
+                                            m=m,
+                                            media_mime=media_mime,
+                                            page_ids=self.page_ids,
+                                            nl2br=self._nl2br)
         out = m.content
         if not out and m.media:
             out = m.media.title
@@ -166,13 +193,19 @@ class Build:
         # Copy the static directory into the output directory.
         for f in [self.config["static_dir"]]:
             target = os.path.join(pubdir, f)
-            if os.path.isfile(f):
+            if self.symlink:
+                os.symlink(os.path.abspath(f), target)
+            elif os.path.isfile(f):
                 shutil.copyfile(f, target)
             else:
                 shutil.copytree(f, target)
 
-        # If media downloading is enabled, copy the media directory.
+        # If media downloading is enabled, copy/symlink the media directory.
         mediadir = self.config["media_dir"]
         if os.path.exists(mediadir):
-            shutil.copytree(mediadir, os.path.join(
-                pubdir, os.path.basename(mediadir)))
+            if self.symlink:
+                os.symlink(os.path.abspath(mediadir), os.path.join(
+                    pubdir, os.path.basename(mediadir)))
+            else:
+                shutil.copytree(mediadir, os.path.join(
+                    pubdir, os.path.basename(mediadir)))
